//-----------------------------------------------------------------------------
// mouseoverdrawer.m
//
// Example of a simple drawer that opens on MouseOver events
//
// created by FrisbeeMonkey
//-----------------------------------------------------------------------------

//                            USING THIS SCRIPT:
//*****************************************************************************
//  1.  Define a MouseOver drawer group in your XML. (see example below)
//  2.  Add your background layer to the group, something like:
//        <layer id="MODrawer" image="player.MODrawer" x="0" y="0" sysregion="1"/>
//        You can change any of the values but the id and sysregion
//  3.  Add a layer to pass info to this script, something like:
//        <layer id="MODrawerInfo" x="54" y="151"/>
//        Set x and y to where you want your drawer to slide to
//  3.  Add any other objects(layers, buttons, sliders, etc) to your group
//  4.  Copy this script (and mouseoverdrawer.maki) to your scripts folder.
//  5.  If you don't have mouseoverdrawer.maki, compile this script.
//  6.  Add this line to the group that you want to be a drawer:
//        <script id="mouseoverdrawer" file="scripts/mouseoverdrawer.maki"/>
//  7.  Refresh your skin(F5) and try it out.
//*****************************************************************************

//                               EXAMPLE XML
//=============================================================================
//<groupdef id="MouseOverDrawerGroup" w="121" h="33">
//
//	 <!-- This layer is the background for the drawer, also catches mouse clicks for opening/closing-->
//     <layer id="MODrawer" image="player.MODrawer" x="0" y="0" sysregion="1" move="0"/>
//
//	 <!-- This layer is the passes info to the drawer script, see script for details +22y-->
//     <layer id="MODrawerInfo" x="54" y="151"/>
//  //add other objects that you want to move with the drawer here
//
//  <script id="mouseoverdrawer" file="scripts/mouseoverdrawer.maki"/>
//</groupdef>
//=============================================================================
//  ***Don't forget to place your group somewhere in your layout!***
//  <group id="DrawerGroup" x="47" y="0"/>

/**
Note:	This is not very useful as is.  The drawer will close when the mouse
		goes over anything you put in the drawer.  I put my animated layers
		in the MAKI skin by setting them ghost="1", but most things you'll want
		to put in the drawer require mouse input.  To add mouse-dependent
		objects (buttons, sliders, etc) make sure they are not ghosted and then
		you will have to add to this script and recompile it.

		You'll need to follow these steps for each object you want to add:
		-Create a new global variable of whatever type(Button, Slider, etc)
			Ex.  Global Button SomeButton;
		-Get the object from the XML
			Ex.  SomeButton = MODrawerGrp.findObject("SomeButtonName");
		-Define an onEnterArea() for your new object
			Ex.  SomeButton.onEnterArea() {
					MODrawerGrp.setTargetX(EndX);
			   		MODrawerGrp.setTargetY(EndY);
					MODrawerGrp.setTargetSpeed(1);
					MODrawerGrp.gotoTarget();
 				 }
 		Doing this for all objects will prevent
**/


// never forget to include std.mi
#include </lib/std.mi>

//declares global variables for use in script
Global Group MODrawerGrp;
Global Layer MODrawer;
Global Button Shuffle;
Global Button Repeat;
Global Text txtTimer;
Global Int MODrawerStatus;  //0 = closed, 1 = open

//when the script is loaded, do this
System.onScriptLoaded() {

	//gets the group that has the objects we want
	MODrawerGrp = getScriptGroup();;

	//now that we have the group, get the layers in the group
	MODrawer = MODrawerGrp.findObject("MODrawer");
	txtTimer = MODrawerGrp.findObject("Timer");
	Shuffle = MODrawerGrp.findObject("Shuffle");
	Repeat = MODrawerGrp.findObject("Repeat");
	//reads and stores the start and end coordinates

}//end onScriptLoaded()

//when the mouse enters the area, do this
MODrawer.onEnterArea() {
      MODrawerGrp.setTargetA(255);  //set the x coordinate you want the MODrawer to slide to
      MODrawerGrp.setTargetSpeed(1);  //sets the speed the MODrawer will slide at(higher is slower)
      MODrawerGrp.gotoTarget();  //now that we have our target values and speed, start moving!
}

//when the mouse leaves the area, do this
MODrawer.onLeaveArea() {
      MODrawerGrp.setTargetA(0);  //set the x coordinate you want the MODrawer to slide back to
      MODrawerGrp.setTargetSpeed(1);  //sets the speed the MODrawer will slide at(higher is slower)
      MODrawerGrp.gotoTarget();  //now that we have our target values and speed, start moving!
}

Shuffle.onEnterArea() {
	MODrawerGrp.setTargetA(255);
	MODrawerGrp.setTargetSpeed(1);  
	MODrawerGrp.gotoTarget();
}

Shuffle.onLeaveArea() {
	MODrawerGrp.setTargetA(0);
	MODrawerGrp.setTargetSpeed(1);  
	MODrawerGrp.gotoTarget();
}

Repeat.onEnterArea() {
	MODrawerGrp.setTargetA(255);
	MODrawerGrp.setTargetSpeed(1);  
	MODrawerGrp.gotoTarget();
}

Repeat.onLeaveArea() {
	MODrawerGrp.setTargetA(0);
	MODrawerGrp.setTargetSpeed(1);  
	MODrawerGrp.gotoTarget();
}

txtTimer.onEnterArea() {
	MODrawerGrp.setTargetA(255);
	MODrawerGrp.setTargetSpeed(1);  
	MODrawerGrp.gotoTarget();
}

txtTimer.onLeaveArea() {
	MODrawerGrp.setTargetA(0);
	MODrawerGrp.setTargetSpeed(1);  
	MODrawerGrp.gotoTarget();
}